"""
Dictionaries module saves all transformations of functions and usages to access the catalogs
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2023 Concordia CERC group
Project Coder Pilar Monsalvete Alvarez de Uribarri pilar.monsalvete@concordia.ca
"""

from hub.helpers.data.hft_function_to_hub_function import HftFunctionToHubFunction
from hub.helpers.data.montreal_custom_fuel_to_hub_fuel import MontrealCustomFuelToHubFuel
from hub.helpers.data.montreal_function_to_hub_function import MontrealFunctionToHubFunction
from hub.helpers.data.eilat_function_to_hub_function import EilatFunctionToHubFunction
from hub.helpers.data.alkis_function_to_hub_function import AlkisFunctionToHubFunction
from hub.helpers.data.pluto_function_to_hub_function import PlutoFunctionToHubFunction
from hub.helpers.data.hub_function_to_nrel_construction_function import HubFunctionToNrelConstructionFunction
from hub.helpers.data.hub_function_to_nrcan_construction_function import HubFunctionToNrcanConstructionFunction
from hub.helpers.data.hub_function_to_eilat_construction_function import HubFunctionToEilatConstructionFunction
from hub.helpers.data.hub_usage_to_comnet_usage import HubUsageToComnetUsage
from hub.helpers.data.hub_usage_to_hft_usage import HubUsageToHftUsage
from hub.helpers.data.hub_usage_to_nrcan_usage import HubUsageToNrcanUsage
from hub.helpers.data.hub_usage_to_eilat_usage import HubUsageToEilatUsage
from hub.helpers.data.montreal_system_to_hub_energy_generation_system import MontrealSystemToHubEnergyGenerationSystem
from hub.helpers.data.montreal_generation_system_to_hub_energy_generation_system import MontrealGenerationSystemToHubEnergyGenerationSystem
from hub.helpers.data.montreal_demand_type_to_hub_energy_demand_type import MontrealDemandTypeToHubEnergyDemandType
from hub.helpers.data.hub_function_to_montreal_custom_costs_function import HubFunctionToMontrealCustomCostsFunction
from hub.helpers.data.north_america_demand_type_to_hub_energy_demand_type import NorthAmericaDemandTypeToHubEnergyDemandType
from hub.helpers.data.north_america_system_to_hub_energy_generation_system import NorthAmericaSystemToHubEnergyGenerationSystem
from hub.helpers.data.north_america_custom_fuel_to_hub_fuel import NorthAmericaCustomFuelToHubFuel
from hub.helpers.data.north_america_storage_system_to_hub_storage import NorthAmericaStorageSystemToHubEnergyStorage


class Dictionaries:
  """
  Dictionaries class
  """

  @property
  def hub_usage_to_hft_usage(self) -> dict:
    """
    Hub usage to HfT usage, transformation dictionary
    :return: dict
    """
    return HubUsageToHftUsage().dictionary

  @property
  def hub_usage_to_comnet_usage(self) -> dict:
    """
    Hub usage to Comnet usage, transformation dictionary
    :return: dict
    """
    return HubUsageToComnetUsage().dictionary

  @property
  def hub_usage_to_nrcan_usage(self) -> dict:
    """
    Get hub usage to NRCAN usage, transformation dictionary
    :return: dict
    """
    return HubUsageToNrcanUsage().dictionary

  @property
  def hub_usage_to_eilat_usage(self) -> dict:
    """
    Hub usage to Eilat usage, transformation dictionary
    :return: dict
    """
    return HubUsageToEilatUsage().dictionary

  @property
  def hub_function_to_nrcan_construction_function(self) -> dict:
    """
    Get hub function to NRCAN construction function, transformation dictionary
    :return: dict
    """
    return HubFunctionToNrcanConstructionFunction().dictionary

  @property
  def hub_function_to_eilat_construction_function(self) -> dict:
    """
    Get hub function to NRCAN construction function, transformation dictionary
    :return: dict
    """
    return HubFunctionToEilatConstructionFunction().dictionary

  @property
  def hub_function_to_nrel_construction_function(self) -> dict:
    """
    Get hub function to NREL construction function, transformation dictionary
    :return: dict
    """
    return HubFunctionToNrelConstructionFunction().dictionary

  @property
  def pluto_function_to_hub_function(self) -> dict:
    """
    Get Pluto function to hub function, transformation dictionary
    :return: dict
    """
    return PlutoFunctionToHubFunction().dictionary

  @property
  def hft_function_to_hub_function(self) -> dict:
    """
    Get Hft function to hub function, transformation dictionary
    :return: dict
    """
    return HftFunctionToHubFunction().dictionary

  @property
  def montreal_function_to_hub_function(self) -> dict:
    """
    Get Montreal function to hub function, transformation dictionary
    """
    return MontrealFunctionToHubFunction().dictionary

  @property
  def alkis_function_to_hub_function(self) -> dict:
    """
    Get Alkis function to hub function, transformation dictionary
    """
    return AlkisFunctionToHubFunction().dictionary

  @property
  def montreal_system_to_hub_energy_generation_system(self):
    """
    Get montreal custom system names to hub energy system names, transformation dictionary
    """
    return MontrealSystemToHubEnergyGenerationSystem().dictionary

  @property
  def montreal_demand_type_to_hub_energy_demand_type(self):
    """
    Get montreal custom system demand type to hub energy demand type, transformation dictionary
    """
    return MontrealDemandTypeToHubEnergyDemandType().dictionary

  @property
  def hub_function_to_montreal_custom_costs_function(self) -> dict:
    """
    Get hub function to Montreal custom costs function, transformation dictionary
    :return: dict
    """
    return HubFunctionToMontrealCustomCostsFunction().dictionary

  @property
  def eilat_function_to_hub_function(self) -> dict:
    """
    Get Eilat's function to hub function, transformation dictionary
    """
    return EilatFunctionToHubFunction().dictionary

  @property
  def montreal_custom_fuel_to_hub_fuel(self) -> dict:
    """
    Get hub fuel from montreal_custom catalog fuel
    """
    return MontrealCustomFuelToHubFuel().dictionary

  @property
  def montreal_generation_system_to_hub_energy_generation_system(self):
    """
    Get montreal custom generation system names to hub energy system names, transformation dictionary
    """
    return MontrealGenerationSystemToHubEnergyGenerationSystem().dictionary

  @property
  def north_america_demand_type_to_hub_energy_demand_type(self):
    """
    Get north america system demand type to hub energy demand type, transformation dictionary
    """
    return NorthAmericaDemandTypeToHubEnergyDemandType().dictionary

  @property
  def north_america_system_to_hub_energy_generation_system(self):
    """
    Get north america system names to hub energy system names, transformation dictionary
    """
    return NorthAmericaSystemToHubEnergyGenerationSystem().dictionary

  @property
  def north_america_custom_fuel_to_hub_fuel(self) -> dict:
    """
    Get hub fuel from north_america catalog fuel
    """
    return NorthAmericaCustomFuelToHubFuel().dictionary

  @property
  def north_america_storage_system_to_hub_storage(self):
    """
    Get montreal custom system names to hub storage system
    """
    return NorthAmericaStorageSystemToHubEnergyStorage().dictionary



import glob
import pathlib
from distutils.util import convert_path

from setuptools import setup

with pathlib.Path('requirements.txt').open() as r:
    install_requires = [
      str(requirement).replace('\n', '')
      for requirement
      in r.readlines()
    ]
install_requires.append('setuptools')

main_ns = {}
version = convert_path('hub/version.py')
with open(version) as f:
  exec(f.read(), main_ns)


setup(
  name='cerc-hub',
  version=main_ns['__version__'],
  description="CERC Hub consist of a set of classes (Central data model), importers and exporters to help researchers "
              "to create better and more sustainable cities",
  long_description="CERC Hub consist of a set of classes (Central data model), importers and exporters to help "
                   "researchers to create better and more sustainable cities.\n\nDeveloped at Concordia university in Canada "
                   "as part of the research group from the Next Generation Cities Institute, our aim among others is "
                   "to provide a comprehensive set of tools to help researchers and urban developers to make decisions "
                   "to improve the livability and efficiency of our cities",
  classifiers=[
        "License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    include_package_data=True,
  packages=['hub',
            'hub.catalog_factories',
            'hub.catalog_factories.construction',
            'hub.catalog_factories.cost',
            'hub.catalog_factories.data_models',
            'hub.catalog_factories.data_models.construction',
            'hub.catalog_factories.data_models.cost',
            'hub.catalog_factories.data_models.energy_systems',
            'hub.catalog_factories.data_models.greenery',
            'hub.catalog_factories.data_models.usages',
            'hub.catalog_factories.energy_systems',
            'hub.catalog_factories.greenery',
            'hub.catalog_factories.greenery.ecore_greenery',
            'hub.catalog_factories.usage',
            'hub.city_model_structure',
            'hub.city_model_structure.attributes',
            'hub.city_model_structure.building_demand',
            'hub.city_model_structure.energy_systems',
            'hub.city_model_structure.greenery',
            'hub.city_model_structure.iot',
            'hub.config',
            'hub.data',
            'hub.exports',
            'hub.exports.building_energy',
            'hub.exports.building_energy.idf_files',
            'hub.exports.building_energy.insel',
            'hub.exports.energy_systems',
            'hub.exports.formats',
            'hub.helpers',
            'hub.helpers.peak_calculation',
            'hub.helpers.data',
            'hub.imports',
            'hub.imports.construction',
            'hub.imports.construction.helpers',
            'hub.imports.energy_systems',
            'hub.imports.geometry',
            'hub.imports.geometry.citygml_classes',
            'hub.imports.geometry.helpers',
            'hub.imports.results',
            'hub.imports.usage',
            'hub.imports.weather',
            'hub.imports.weather.helpers',
            'hub.persistence',
            'hub.persistence.models',
            'hub.persistence.repositories',
            'hub.imports'
            ],
  setup_requires=install_requires,
  install_requires=install_requires,
  data_files=[
    ('hub', glob.glob('requirements.txt')),
    ('hub/config', glob.glob('hub/config/*.ini')),
    ('hub/catalog_factories/greenery/ecore_greenery',
     glob.glob('hub/catalog_factories/greenery/ecore_greenery/*.ecore')),
    ('hub/data/construction', glob.glob('hub/data/construction/*')),
    ('hub/data/costs', glob.glob('hub/data/costs/montreal_costs.xml')),
    ('hub/data/customized_imports', glob.glob('hub/data/customized_imports/ashrae_archetypes.xml')),
    ('hub/data/energy_systems', glob.glob('hub/data/energy_systems/*.xml')),
    ('hub/data/energy_systems/heat_pumps', glob.glob('hub/data/energy_systems/heat_pumps/*.xml')),
    ('hub/data/energy_systems/heat_pumps', glob.glob('hub/data/energy_systems/heat_pumps/*.insel')),
    ('hub/data/energy_systems/heat_pumps', glob.glob('hub/data/energy_systems/heat_pumps/*.xlsx')),
    ('hub/data/energy_systems/heat_pumps', glob.glob('hub/data/energy_systems/heat_pumps/*.txt')),
    ('hub/data/energy_systems/heat_pumps', glob.glob('hub/data/energy_systems/heat_pumps/*.yaml')),
    ('hub/data/geolocation', glob.glob('hub/data/geolocation/*.txt')),
    ('hub/data/greenery', glob.glob('hub/data/greenery/*.xml')),
    ('hub/data/usage', glob.glob('hub/data/usage/*.xml')),
    ('hub/data/usage', glob.glob('hub/data/usage/*.json')),
    ('hub/data/usage', glob.glob('hub/data/usage/*.xlsx')),
    ('hub/data/weather', glob.glob('hub/data/weather/*.dat')),
    ('hub/data/weather/epw', glob.glob('hub/data/weather/epw/*.epw')),
    ('hub/data/weather', glob.glob('hub/data/weather/*.dat')),
    ('hub/exports/building_energy/idf_files', glob.glob('hub/exports/building_energy/idf_files/*.idf')),
    ('hub/exports/building_energy/idf_files', glob.glob('hub/exports/building_energy/idf_files/*.idd'))
  ],

)